<a name="notification"></a>
  {% block notification %}
  {% endblock %}

  {% if messages %}
  <div class="notification">
    {% for message in messages %}
	<div class="alert alert-{% if message.tags %}{{ message.tags }}{% endif %}">
	  <button type="button" class="close" data-dismiss="alert">×</button>
	  {{ message }}
	</div>
    {% endfor %}
  </div>
  {% endif %}
