<div class="modal hide fade" id="modal-archive">
    <div class="modal-header">
        <button class="close" data-dismiss="modal">&times;</button>
        <h3>Modal header</h3>
    </div>
    <div class="modal-body">
	  Body
    </div>
    <div class="modal-footer">
        <a href="#" class="btn" data-dismiss="modal">Close</a>
    </div>
</div>


